==> public-sdk-2.0.26-sources.jar: com/voxeet/sdk/core/abs/promises/UnsubscribeConferenceEventPromiseable.java <==
package com.voxeet.sdk.core.abs.promises;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.voxeet.sdk.core.abs.AbstractConferenceSdkObservableProvider;
import com.voxeet.sdk.core.abs.AbstractPromiseable;
import com.voxeet.sdk.core.abs.ConferenceService;
import com.voxeet.sdk.core.abs.information.ConferenceInformation;
import com.voxeet.sdk.core.http.HttpCallback;
import com.voxeet.sdk.core.http.HttpHelper;
import com.voxeet.sdk.core.services.MediaService;
import com.voxeet.sdk.events.error.HttpException;
import com.voxeet.sdk.events.success.UnSubscribeConferenceAnswerEvent;

import org.greenrobot.eventbus.EventBus;

import eu.codlab.simplepromise.Promise;
import eu.codlab.simplepromise.solve.PromiseSolver;
import eu.codlab.simplepromise.solve.Solver;
import okhttp3.ResponseBody;
import retrofit2.Call;
import retrofit2.Response;

public class UnsubscribeConferenceEventPromiseable extends AbstractPromiseable<Boolean> {

    public UnsubscribeConferenceEventPromiseable(@NonNull ConferenceService parent, @NonNull MediaService mediaService, @NonNull AbstractConferenceSdkObservableProvider provider, @Nullable ConferenceInformation information, @NonNull EventBus eventBus) {
        super(parent, mediaService, provider, information, eventBus);
    }

    @NonNull
    @Override
    public Promise<Boolean> createPromise() {
        return new Promise<>(new PromiseSolver<Boolean>() {
            @Override
            public void onCall(@NonNull final Solver<Boolean> solver) {
                Call<ResponseBody> call = getProvider().getUnSubscribeObservable(getInformation().getConference().getConferenceId());
                HttpHelper.enqueue(call, new HttpCallback<ResponseBody>() {
                    @Override
                    public void onSuccess(@NonNull ResponseBody object, @NonNull Response<ResponseBody> response) {
                        log("You are no longer subscribed to this mConference's events");

                        getEventBus().post(new UnSubscribeConferenceAnswerEvent(response.code() == 200));
                        solver.resolve(true);
                    }

                    @Override
                    public void onFailure(@NonNull Throwable e, @Nullable Response<ResponseBody> response) {
                        HttpException.dumpErrorResponse(response);

                        log("Failed to unsubscribe from this mConference's events");

                        getEventBus().post(new UnSubscribeConferenceAnswerEvent(false, getParent().handleError(e)));
                        solver.reject(e);
                    }
                });
            }
        });
    }
}

==> public-sdk-2.0.30-sources.jar: com/voxeet/sdk/core/abs/promises/UnsubscribeConferenceEventPromiseable.java <==
package com.voxeet.sdk.core.abs.promises;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.voxeet.sdk.core.abs.AbstractPromiseable;
import com.voxeet.sdk.core.abs.ConferenceService;
import com.voxeet.sdk.core.abs.information.ConferenceInformation;
import com.voxeet.sdk.core.abs.ConferenceSdkObservableProvider;
import com.voxeet.sdk.utils.HttpHelper;
import com.voxeet.sdk.core.services.MediaService;
import com.voxeet.sdk.events.error.HttpException;
import com.voxeet.sdk.events.success.UnSubscribeConferenceAnswerEvent;

import org.greenrobot.eventbus.EventBus;

import eu.codlab.simplepromise.Promise;
import eu.codlab.simplepromise.solve.PromiseSolver;
import eu.codlab.simplepromise.solve.Solver;
import okhttp3.ResponseBody;
import retrofit2.Call;
import retrofit2.Response;

public class UnsubscribeConferenceEventPromiseable extends AbstractPromiseable<Boolean> {

    public UnsubscribeConferenceEventPromiseable(@NonNull ConferenceService parent, @NonNull MediaService mediaService, @NonNull ConferenceSdkObservableProvider provider, @Nullable ConferenceInformation information, @NonNull EventBus eventBus) {
        super(parent, mediaService, provider, information, eventBus);
    }

    @NonNull
    @Override
    public Promise<Boolean> createPromise() {
        return new Promise<>(new PromiseSolver<Boolean>() {
            @Override
            public void onCall(@NonNull final Solver<Boolean> solver) {
                Call<ResponseBody> call = getProvider().getUnSubscribeObservable(getInformation().getConference().getConferenceId());
                HttpHelper.enqueue(call, new HttpHelper.HttpCallback<ResponseBody>() {
                    @Override
                    public void onSuccess(@NonNull ResponseBody object, @NonNull Response<ResponseBody> response) {
                        log("You are no longer subscribed to this mConference's events");

                        getEventBus().post(new UnSubscribeConferenceAnswerEvent(response.code() == 200));
                        solver.resolve(true);
                    }

                    @Override
                    public void onFailure(@NonNull Throwable e, @Nullable Response<ResponseBody> response) {
                        HttpException.dumpErrorResponse(response);

                        log("Failed to unsubscribe from this mConference's events");

                        getEventBus().post(new UnSubscribeConferenceAnswerEvent(false, getParent().handleError(e)));
                        solver.reject(e);
                    }
                });
            }
        });
    }
}
